% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Q10.R
\encoding{UTF-8}
\name{Q10}
\alias{Q10}
\title{Parameters of Q10 Temperature Coefficient}
\usage{
Q10(Q10, R1, R2, T1, T2)
}
\arguments{
\item{Q10}{factor by which rate changes due to 10 °C increase in temperature.}

\item{R1}{rate 1.}

\item{R2}{rate 2.}

\item{T1}{temperature 1 (in °C).}

\item{T2}{temperature 2 (in °C).}
}
\description{
Returns the unknown parameter given 4 of 5 parameters from Q10 temperature coefficient calculation for chemical or biological systems.
}
\details{
Given four parameters, the fifth parameter will be returned.
}
\examples{
Q10(R1 = 5, R2 = 10, T1 = 10, T2 = 20) # Returns Q10; = 2
Q10(Q10 = 2.66, R1 = 5, T1 = 10, T2 = 20) # Returns R2; = 13.3

# My species has an MO2 of 9.5 umol/g/h at 10 *C. What MO2 should I expect at 13 *C?
Q10(Q10 = 2, R1 = 9.5, T1 = 10, T2 = 13) # expect ~11.7 umol/g/h at 13 *C.

# A 100 g individual at 10 *C has an MO2 of 1270 umol/h. How much
# would a 250 g individual likely consume at 14 *C?
Q10(Q10 = 2, R1 = scale_MO2(mass_1 = 100, MO2_1 = 1270, mass_2 = 250)$MO2_2, T1 = 10, T2 = 14)

# Visualize MO2 scaling by mass and temperature:
mass = seq(10, 200, 10)
temp = 10:25
base_mass = 50
base_temp = 20
base_MO2 = 750
mo2 = outer(mass, temp, function(mass, temp){
	scale_MO2(mass_1 = base_mass, mass_2 = mass, MO2_1 = Q10(Q10 = 2, R1 = base_MO2,
	 T1 = base_temp, T2 = temp)$R2)$MO2_2
})
persp(mass, temp, mo2, xlab = 'Mass (g)', ylab = 'Temperature (*C)', zlab = 'MO2 (umol / hr)',
 theta = 35, phi = 15, expand = 0.5, ticktype = 'detailed', nticks = 10)

}
\author{
Matthew A. Birk, \email{matthewabirk@gmail.com}
}
\seealso{
\code{\link{scale_MO2}}
}

